@@ -1,10 +1,11 @@
+from box import Box, BoxList
 from restfly.endpoint import APIEndpoint
-from pyzscaler.utils import snake_to_camel
-from box import BoxList
+
+from pyzscaler.utils import convert_keys, snake_to_camel
 
 
 class URLCategoriesAPI(APIEndpoint):
-    def lookup(self, urls: list):
+    def lookup(self, urls: list) -> BoxList:
         """
         Lookup the category for the provided URLs.
 
@@ -13,7 +14,7 @@ class URLCategoriesAPI(APIEndpoint):
                 The list of URLs to perform a category lookup on.
 
         Returns:
-            :obj:`list`: A list of URL category reports.
+            :obj:`BoxList`: A list of URL category reports.
 
         Examples:
             >>> zia.url_categories.lookup(['example.com', 'test.com'])
@@ -21,9 +22,9 @@ class URLCategoriesAPI(APIEndpoint):
         """
         payload = urls
 
-        return self._post("urlLookup", json=payload, box=BoxList)
+        return self._post("urlLookup", json=payload)
 
-    def list_categories(self, custom_only: bool = False):
+    def list_categories(self, custom_only: bool = False) -> BoxList:
         """
         Returns information on URL categories.
 
@@ -32,7 +33,7 @@ class URLCategoriesAPI(APIEndpoint):
                 Returns only custom categories if True.
 
         Returns:
-            :obj:`list`: A list of information for all or custom URL categories.
+            :obj:`BoxList`: A list of information for all or custom URL categories.
 
         Examples:
             List all URL categories:
@@ -45,14 +46,14 @@ class URLCategoriesAPI(APIEndpoint):
 
         """
 
-        return self._get(f"urlCategories?customOnly={custom_only}", box=BoxList)
+        return self._get(f"urlCategories?customOnly={custom_only}")
 
-    def get_quota(self):
+    def get_quota(self) -> Box:
         """
         Returns information on URL category quota usage.
 
         Returns:
-            :obj:`dict`: The URL quota statistics.
+            :obj:`Box`: The URL quota statistics.
 
         Examples:
             >>> zia.url_categories.get_quota()
@@ -61,7 +62,7 @@ class URLCategoriesAPI(APIEndpoint):
 
         return self._get("urlCategories/urlQuota")
 
-    def get_category(self, category_id: str):
+    def get_category(self, category_id: str) -> Box:
         """
         Returns URL category information for the provided category.
 
@@ -70,7 +71,7 @@ class URLCategoriesAPI(APIEndpoint):
                 The unique identifier for the category (e.g. 'MUSIC')
 
         Returns:
-            :obj:`dict`: The resource record for the category.
+            :obj:`Box`: The resource record for the category.
 
         Examples:
             >>> zia.url_categories.get_category('ALCOHOL_TOBACCO')
@@ -78,7 +79,7 @@ class URLCategoriesAPI(APIEndpoint):
         """
         return self._get(f"urlCategories/{category_id}")
 
-    def add_url_category(self, name: str, super_category: str, urls: list, **kwargs):
+    def add_url_category(self, name: str, super_category: str, urls: list, **kwargs) -> Box:
         """
         Adds a new custom URL category.
 
@@ -97,9 +98,11 @@ class URLCategoriesAPI(APIEndpoint):
                 URLs entered will be covered by policies that reference the parent category, in addition to this one.
             description (str):
                 Description of the category.
+            custom_category (bool):
+                Set to true for custom URL category. Up to 48 custom URL categories can be added per organisation.
 
         Returns:
-            :obj:`dict`: The newly configured custom URL category resource record.
+            :obj:`Box`: The newly configured custom URL category resource record.
 
         Examples:
             Add a new category for beers that don't taste good:
@@ -124,7 +127,7 @@ class URLCategoriesAPI(APIEndpoint):
 
         return self._post("urlCategories", json=payload)
 
-    def add_tld_category(self, name: str, tlds: list, **kwargs):
+    def add_tld_category(self, name: str, tlds: list, **kwargs) -> Box:
         """
         Adds a new custom TLD category.
 
@@ -141,7 +144,7 @@ class URLCategoriesAPI(APIEndpoint):
                 Description of the category.
 
         Returns:
-            :obj:`dict`: The newly configured custom TLD category resource record.
+            :obj:`Box`: The newly configured custom TLD category resource record.
 
         Examples:
             Create a category for all 'developer' sites:
@@ -165,7 +168,7 @@ class URLCategoriesAPI(APIEndpoint):
 
         return self._post("urlCategories", json=payload)
 
-    def update_url_category(self, category_id: str, **kwargs):
+    def update_url_category(self, category_id: str, **kwargs) -> Box:
         """
         Updates a URL category.
 
@@ -186,7 +189,7 @@ class URLCategoriesAPI(APIEndpoint):
                 Description of the category.
 
         Returns:
-            :obj:`dict`: The updated URL category resource record.
+            :obj:`Box`: The updated URL category resource record.
 
         Examples:
             Update the name of a category:
@@ -201,13 +204,7 @@ class URLCategoriesAPI(APIEndpoint):
 
         """
 
-        # Cache existing record for defaulting mandatory fields that may not require updating.
-        category_record = self.get_category(category_id)
-
-        payload = {
-            # configuredName required
-            "configuredName": kwargs.pop("name", category_record.configured_name)
-        }
+        payload = convert_keys(self.get_category(category_id))
 
         # Add optional parameters to payload
         for key, value in kwargs.items():
@@ -215,7 +212,7 @@ class URLCategoriesAPI(APIEndpoint):
 
         return self._put(f"urlCategories/{category_id}", json=payload)
 
-    def add_urls_to_category(self, category_id: str, urls: list):
+    def add_urls_to_category(self, category_id: str, urls: list) -> Box:
         """
         Adds URLS to a URL category.
 
@@ -226,7 +223,7 @@ class URLCategoriesAPI(APIEndpoint):
                 Custom URLs to add to a URL category.
 
         Returns:
-            :obj:`dict`: The updated URL category resource record.
+            :obj:`Box`: The updated URL category resource record.
 
         Examples:
             >>> zia.url_categories.add_urls_to_category('CUSTOM_01',
@@ -234,19 +231,12 @@ class URLCategoriesAPI(APIEndpoint):
 
         """
 
-        # Cache existing record for defaulting mandatory fields that may not require updating.
-        category_record = self.get_category(category_id)
+        payload = convert_keys(self.get_category(category_id))
+        payload["urls"] = urls
 
-        payload = {
-            "configuredName": category_record.configured_name,  # configuredName required.
-            "urls": urls,
-        }
+        return self._put(f"urlCategories/{category_id}?action=ADD_TO_LIST", json=payload)
 
-        return self._put(
-            f"urlCategories/{category_id}?action=ADD_TO_LIST", json=payload
-        )
-
-    def delete_urls_from_category(self, category_id: str, urls: list):
+    def delete_urls_from_category(self, category_id: str, urls: list) -> Box:
         """
         Adds URLS to a URL category.
 
@@ -257,7 +247,7 @@ class URLCategoriesAPI(APIEndpoint):
                 Custom URLs to delete from a URL category.
 
         Returns:
-            :obj:`dict`: The updated URL category resource record.
+            :obj:`Box`: The updated URL category resource record.
 
         Examples:
             >>> zia.url_categories.delete_urls_from_category('CUSTOM_01',
@@ -265,19 +255,12 @@ class URLCategoriesAPI(APIEndpoint):
 
         """
 
-        # Cache existing record for defaulting mandatory fields that may not require updating.
-        category_record = self.get_category(category_id)
+        payload = convert_keys(self.get_category(category_id))
+        payload["urls"] = urls
 
-        payload = {
-            "configuredName": category_record.configured_name,  # configuredName required.
-            "urls": urls,
-        }
+        return self._put(f"urlCategories/{category_id}?action=REMOVE_FROM_LIST", json=payload)
 
-        return self._put(
-            f"urlCategories/{category_id}?action=REMOVE_FROM_LIST", json=payload
-        )
-
-    def delete_category(self, category_id: str):
+    def delete_category(self, category_id: str) -> int:
         """
         Deletes the specified URL category.
 
@@ -286,7 +269,7 @@ class URLCategoriesAPI(APIEndpoint):
                 The unique identifier for the category.
 
         Returns:
-            :obj:`str`: The status code for the operation.
+            :obj:`int`: The status code for the operation.
 
         Examples:
             >>> zia.url_categories.delete_category('CUSTOM_01')
